summaryrefslogtreecommitdiffstats
path: root/src/replaygainfilelist.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commitc9f922159a1ce0496d3bbe743d590221f00148f8 (patch)
tree549c6dbce91dea78f999450ea9442b815ee365b7 /src/replaygainfilelist.h
parent3a2300ed7cee06b5b49c4bc71f38d5cee72171b5 (diff)
downloadsoundkonverter-c9f922159a1ce0496d3bbe743d590221f00148f8.tar.gz
soundkonverter-c9f922159a1ce0496d3bbe743d590221f00148f8.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/soundkonverter@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/replaygainfilelist.h')
-rwxr-xr-xsrc/replaygainfilelist.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/replaygainfilelist.h b/src/replaygainfilelist.h
index 1228aea..6cd882c 100755
--- a/src/replaygainfilelist.h
+++ b/src/replaygainfilelist.h
@@ -44,22 +44,22 @@ public:
/**
* Constructor
* @param tqparent The tqparent list view
*/
- ReplayGainFileListItem( TQListView* tqparent );
+ ReplayGainFileListItem( TQListView* parent );
/*
* Constructor
* @param tqparent The tqparent list view
* @param after The item, the new item should be placed after
*/
- //ReplayGainFileListItem( TQListView* tqparent, TQListViewItem* after );
+ //ReplayGainFileListItem( TQListView* parent, TQListViewItem* after );
/**
* Constructor
* @param tqparent The tqparent list view item
*/
- ReplayGainFileListItem( ReplayGainFileListItem* tqparent );
+ ReplayGainFileListItem( ReplayGainFileListItem* parent );
/**
* Destructor
@@ -75,7 +75,7 @@ public:
ReplayGainFileListItem* firstChild() const { return static_cast<ReplayGainFileListItem*>( KListViewItem::firstChild() ); }
ReplayGainFileListItem* nextSibling() const { return static_cast<ReplayGainFileListItem*>( KListViewItem::nextSibling() ); }
//ReplayGainFileListItem* itemBelow() { return static_cast<ReplayGainFileListItem*>( KListViewItem::itemBelow() ); }
- ReplayGainFileListItem* tqparent() const { return static_cast<ReplayGainFileListItem*>( KListViewItem::tqparent() ); }
+ ReplayGainFileListItem* parent() const { return static_cast<ReplayGainFileListItem*>( KListViewItem::parent() ); }
Type type() { return m_type; }
void setType( Type );
@@ -113,10 +113,10 @@ class ReplayGainFileList : public KListView
public:
/**
* Constructor
* @param tqparent The tqparent widget
* @param name The name of the file list
*/
- ReplayGainFileList( TagEngine*, Config*, Logger*, TQWidget *tqparent=0, const char *name=0 );
+ ReplayGainFileList( TagEngine*, Config*, Logger*, TQWidget *parent=0, const char *name=0 );
/**
* Destructor
@@ -44,22 +44,22 @@ public:
/**
* Constructor
- * @param tqparent The tqparent list view
+ * @param parent The parent list view
*/
@@ -44,22 +44,22 @@ public:
/*
* Constructor
- * @param tqparent The tqparent list view
+ * @param parent The parent list view
* @param after The item, the new item should be placed after
*/
@@ -44,22 +44,22 @@ public:
/**
* Constructor
- * @param tqparent The tqparent list view item
+ * @param parent The parent list view item
*/
@@ -113,10 +113,10 @@ class ReplayGainFileList : public KListView
/**
* Constructor
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
* @param name The name of the file list
*/